import * as Dialog from "@radix-ui/react-dialog";
import {
  DialogBody,
  DialogClose,
  DialogContent,
  DialogHeader,
  DialogOverlay,
} from "@/components/Shared/Dialog.styled";
import { IconClear } from "@/components/Shared/SVG/Icons";
import { ReactNode } from "react";

interface SharedDialogProps {
  children: ReactNode;
  handleCloseClick: () => void;
  isOpen: boolean;
  large?: boolean;
  title: string;
}

const SharedDialog: React.FC<SharedDialogProps> = ({
  children,
  handleCloseClick,
  large,
  isOpen,
  title,
}) => {
  return (
    <Dialog.Root open={isOpen}>
      <Dialog.Portal>
        <DialogOverlay />
        <DialogContent
          onInteractOutside={handleCloseClick}
          {...(large && { size: "large" })}
        >
          <DialogHeader>
            <Dialog.Title>{title}</Dialog.Title>
            <DialogClose
              data-testid="facets-filter-close"
              aria-label="Cancel"
              onClick={handleCloseClick}
            >
              <IconClear />
            </DialogClose>
          </DialogHeader>
          <DialogBody>{children}</DialogBody>
        </DialogContent>
      </Dialog.Portal>
    </Dialog.Root>
  );
};

export default SharedDialog;
